step_count() creates a specification of a recipe step that will create a
variable that counts instances of a regular expression pattern in text.
step_count(
recipe,
...,
role = "predictor",
trained = FALSE,
pattern = ".",
normalize = FALSE,
options = list(),
result = make.names(pattern),
input = NULL,
sparse = "auto",
keep_original_cols = TRUE,
skip = FALSE,
id = rand_id("count")
)An updated version of recipe with the new step added to the
sequence of any existing operations.
A recipe object. The step will be added to the sequence of operations for this recipe.
A single selector function to choose which variable will be
searched for the regex pattern. The selector should resolve to a single
variable. See selections() for more details.
For model terms created by this step, what analysis role should they be assigned? By default, the new columns created by this step from the original variables will be used as predictors in a model.
A logical to indicate if the quantities for preprocessing have been estimated.
A character string containing a regular expression (or
character string for fixed = TRUE) to be matched in the given character
vector. Coerced by as.character to a character string if possible.
A logical; should the integer counts be divided by the total number of characters in the string?.
A list of options to gregexpr() that should not include x
or pattern.
A single character value for the name of the new variable. It should be a valid column name.
A single character value for the name of the variable being
searched. This is NULL until computed by prep().
A single string. Should the columns produced be sparse vectors.
Can take the values "yes", "no", and "auto". If sparse = "auto"
then workflows can determine the best option. Defaults to "auto".
A logical to keep the original variables in the
output. Defaults to TRUE.
A logical. Should the step be skipped when the recipe is baked by
bake()? While all operations are baked when prep() is run, some
operations may not be able to be conducted on new data (e.g. processing the
outcome variable(s)). Care should be taken when using skip = TRUE as it
may affect the computations for subsequent operations.
A character string that is unique to this step to identify it.
When you tidy() this step, a tibble is returned with
columns terms, result , and id:
character, the selectors or variables selected
character, the new column names
character, id of this step
This step produces sparse columns if sparse = "yes" is being set. The
default value "auto" won't trigger production fo sparse columns if a recipe
is prep()ed, but allows for a workflow to toggle to "yes" or "no"
depending on whether the model supports sparse_data and if the model is
is expected to run faster with the data.
The mechanism for determining how much sparsity is produced isn't perfect,
and there will be times when you want to manually overwrite by setting
sparse = "yes" or sparse = "no".
The underlying operation does not allow for case weights.
Other dummy variable and encoding steps:
step_bin2factor(),
step_date(),
step_dummy(),
step_dummy_extract(),
step_dummy_multi_choice(),
step_factor2string(),
step_holiday(),
step_indicate_na(),
step_integer(),
step_novel(),
step_num2factor(),
step_ordinalscore(),
step_other(),
step_regex(),
step_relevel(),
step_string2factor(),
step_time(),
step_unknown(),
step_unorder()
data(covers, package = "modeldata")
rec <- recipe(~description, covers) |>
step_count(description, pattern = "(rock|stony)", result = "rocks") |>
step_count(description, pattern = "famil", normalize = TRUE)
rec2 <- prep(rec, training = covers)
rec2
count_values <- bake(rec2, new_data = covers)
count_values
tidy(rec, number = 1)
tidy(rec2, number = 1)
Run the code above in your browser using DataLab