- recipe
A recipe object. The step will be added to the sequence of
operations for this recipe.
- ...
One or more selector functions to choose variables for this step.
See selections() for more details.
- role
For model terms created by this step, what analysis role should
they be assigned? By default, the new columns created by this step from the
original variables will be used as predictors in a model.
- trained
A logical to indicate if the quantities for preprocessing have
been estimated.
- deg_free
The degrees of freedom for the b-spline. As the degrees of
freedom for a b-spline increase, more flexible and complex curves can be
generated.
- degree
The degree of I-spline defined to be the degree of the
associated M-spline instead of actual polynomial degree. For example,
I-spline basis of degree 2 is defined as the integral of associated
M-spline basis of degree 2.
- complete_set
If TRUE, the complete basis matrix will be returned.
Otherwise, the first basis will be excluded from the output. This maps to
the intercept argument of the corresponding function from the
splines2 package and has the same default value.
- options
A list of options for splines2::iSpline() which should not
include x, df, degree, periodic, or intercept.
- keep_original_cols
A logical to keep the original variables in the
output. Defaults to FALSE.
- results
A list of objects created once the step has been trained.
- skip
A logical. Should the step be skipped when the recipe is baked by
bake()? While all operations are baked when prep() is run, some
operations may not be able to be conducted on new data (e.g. processing the
outcome variable(s)). Care should be taken when using skip = TRUE as it
may affect the computations for subsequent operations.
- id
A character string that is unique to this step to identify it.