When working with the rsample package, a simple recipe must be
prepared using the prep function first. When using recipes with
rsample it is helpful to have a function that can prepare a recipe
across a series of split objects that are produced in this package.
prepper is a wrapper function around prep() that can be used to do this.
See the vignette on "Recipes and rsample" for an example.
prepper(split_obj, recipe, ...)An rplit object
An untrained recipe object.
Arguments to pass to prep such as verbose or retain.
prepper() sets the underlying prep() argument fresh to TRUE.