step_date() creates a specification of a recipe step that will convert
date data into one or more factor or numeric variables.
step_date(
recipe,
...,
role = "predictor",
trained = FALSE,
features = c("dow", "month", "year"),
abbr = TRUE,
label = TRUE,
ordinal = FALSE,
locale = clock::clock_locale()$labels,
columns = NULL,
keep_original_cols = TRUE,
skip = FALSE,
id = rand_id("date")
)An updated version of recipe with the new step added to the
sequence of any existing operations.
A recipe object. The step will be added to the sequence of operations for this recipe.
One or more selector functions to choose variables for this step.
The selected variables should have class Date or POSIXct. See
selections() for more details.
For model terms created by this step, what analysis role should they be assigned? By default, the new columns created by this step from the original variables will be used as predictors in a model.
A logical to indicate if the quantities for preprocessing have been estimated.
A character string that includes at least one of the
following values: month, dow (day of week), mday (day of month),
doy (day of year), week, month, decimal (decimal date, e.g.
2002.197), quarter, semester, year.
A logical. Only available for features month or dow. FALSE
will display the day of the week as an ordered factor of character strings,
such as "Sunday". TRUE will display an abbreviated version of the label,
such as "Sun". abbr is disregarded if label = FALSE.
A logical. Only available for features month or dow. TRUE
will display the day of the week as an ordered factor of character strings,
such as "Sunday." FALSE will display the day of the week as a number.
A logical: should factors be ordered? Only available for
features month or dow.
Locale to be used for month and dow, see locales. On
Linux systems you can use system("locale -a") to list all the installed
locales. Can be a locales string, or a clock::clock_labels() object.
Defaults to clock::clock_locale()$labels.
A character string of the selected variable names. This field
is a placeholder and will be populated once prep() is used.
A logical to keep the original variables in the
output. Defaults to TRUE.
A logical. Should the step be skipped when the recipe is baked by
bake()? While all operations are baked when prep() is run, some
operations may not be able to be conducted on new data (e.g. processing the
outcome variable(s)). Care should be taken when using skip = TRUE as it
may affect the computations for subsequent operations.
A character string that is unique to this step to identify it.
When you tidy() this step, a tibble is returned with
columns terms, value, ordinal , and id:
character, the selectors or variables selected
character, the feature names
logical, are factors ordered
character, id of this step
The underlying operation does not allow for case weights.
Unlike some other steps, step_date() does not remove the original date
variables by default. Set keep_original_cols to FALSE to remove them.
See step_time() if you want to calculate features that are smaller than
days.
Other dummy variable and encoding steps:
step_bin2factor(),
step_count(),
step_dummy(),
step_dummy_extract(),
step_dummy_multi_choice(),
step_factor2string(),
step_holiday(),
step_indicate_na(),
step_integer(),
step_novel(),
step_num2factor(),
step_ordinalscore(),
step_other(),
step_regex(),
step_relevel(),
step_string2factor(),
step_time(),
step_unknown(),
step_unorder()
library(lubridate)
examples <- data.frame(
Dan = ymd("2002-03-04") + days(1:10),
Stefan = ymd("2006-01-13") + days(1:10)
)
date_rec <- recipe(~ Dan + Stefan, examples) |>
step_date(all_predictors())
tidy(date_rec, number = 1)
date_rec <- prep(date_rec, training = examples)
date_values <- bake(date_rec, new_data = examples)
date_values
tidy(date_rec, number = 1)
Run the code above in your browser using DataLab