- recipe
A recipe object. The step will be added to the sequence of
operations for this recipe.
- ...
One or more selector functions to choose variables for this step.
See selections() for more details.
- class
A bare name that specifies a single categorical variable to be
used as the class. Can also be a string or tidyselect for backwards
compatibility.
- role
For model terms created by this step, what analysis role should
they be assigned? By default, the new columns created by this step from the
original variables will be used as predictors in a model.
- trained
A logical to indicate if the quantities for preprocessing have
been estimated.
- metric
A character string specifying the depth metric. Possible values
are "potential", "halfspace", "Mahalanobis", "simplicialVolume",
"spatial", and "zonoid".
- options
A list of options to pass to the underlying depth functions.
See ddalpha::depth.halfspace(), ddalpha::depth.Mahalanobis(),
ddalpha::depth.potential(), ddalpha::depth.projection(),
ddalpha::depth.simplicial(), ddalpha::depth.simplicialVolume(),
ddalpha::depth.spatial(), ddalpha::depth.zonoid().
- data
The training data are stored here once after prep() is
executed.
- prefix
A character string for the prefix of the resulting new
variables. See notes below.
- keep_original_cols
A logical to keep the original variables in the
output. Defaults to TRUE.
- skip
A logical. Should the step be skipped when the recipe is baked by
bake()? While all operations are baked when prep() is run, some
operations may not be able to be conducted on new data (e.g. processing the
outcome variable(s)). Care should be taken when using skip = TRUE as it
may affect the computations for subsequent operations.
- id
A character string that is unique to this step to identify it.