step_pca() creates a specification of a recipe step that will convert
numeric variables into one or more principal components.
step_pca(
recipe,
...,
role = "predictor",
trained = FALSE,
num_comp = 5,
threshold = NA,
options = list(),
res = NULL,
columns = NULL,
prefix = "PC",
keep_original_cols = FALSE,
skip = FALSE,
id = rand_id("pca")
)An updated version of recipe with the new step added to the
sequence of any existing operations.
A recipe object. The step will be added to the sequence of operations for this recipe.
One or more selector functions to choose variables for this step.
See selections() for more details.
For model terms created by this step, what analysis role should they be assigned? By default, the new columns created by this step from the original variables will be used as predictors in a model.
A logical to indicate if the quantities for preprocessing have been estimated.
The number of components to retain as new predictors. If
num_comp is greater than the number of columns or the number of possible
components, a smaller value will be used. If num_comp = 0 is set then no
transformation is done and selected variables will stay unchanged,
regardless of the value of keep_original_cols.
A fraction of the total variance that should be covered by
the components. For example, threshold = .75 means that step_pca()
should generate enough components to capture 75 percent of the variability
in the variables. Note: using this argument will override and reset any
value given to num_comp.
A list of options to the default method for stats::prcomp().
Argument defaults are set to retx = FALSE, center = FALSE, scale. = FALSE, and tol = NULL. Note that the argument x should not be
passed here (or at all).
The stats::prcomp.default() object is stored here once this
preprocessing step has be trained by prep().
A character string of the selected variable names. This field
is a placeholder and will be populated once prep() is used.
A character string for the prefix of the resulting new variables. See notes below.
A logical to keep the original variables in the
output. Defaults to FALSE.
A logical. Should the step be skipped when the recipe is baked by
bake()? While all operations are baked when prep() is run, some
operations may not be able to be conducted on new data (e.g. processing the
outcome variable(s)). Care should be taken when using skip = TRUE as it
may affect the computations for subsequent operations.
A character string that is unique to this step to identify it.
When you tidy() this step two things can happen depending
the type argument. If type = "coef" a tibble returned with 4 columns
terms, value, component , and id:
character, the selectors or variables selected
numeric, variable loading
character, principle component
character, id of this step
If type = "variance" a tibble returned with 4 columns terms, value,
component , and id:
character, type of variance
numeric, value of the variance
integer, principle component
character, id of this step
This step has 2 tuning parameters:
num_comp: # Components (type: integer, default: 5)
threshold: Threshold (type: double, default: NA)
This step performs an unsupervised operation that can utilize case weights.
As a result, case weights are only used with frequency weights. For more
information, see the documentation in case_weights and the examples on
tidymodels.org.
Principal component analysis (PCA) is a transformation of a group of variables that produces a new set of artificial features or components. These components are designed to capture the maximum amount of information (i.e. variance) in the original variables. Also, the components are statistically independent from one another. This means that they can be used to combat large inter-variables correlations in a data set.
It is advisable to standardize the variables prior to running PCA. Here, each
variable will be centered and scaled prior to the PCA calculation. This can
be changed using the options argument or by using step_center() and
step_scale().
The argument num_comp controls the number of components that will be retained
(the original variables that are used to derive the components are removed from
the data). The new components will have names that begin with prefix and a
sequence of numbers. The variable names are padded with zeros. For example, if
num_comp < 10, their names will be PC1 - PC9. If num_comp = 101,
the names would be PC1 - PC101.
Alternatively, threshold can be used to determine the number of components
that are required to capture a specified fraction of the total variance in
the variables.
Jolliffe, I. T. (2010). Principal Component Analysis. Springer.
Other multivariate transformation steps:
step_classdist(),
step_classdist_shrunken(),
step_depth(),
step_geodist(),
step_ica(),
step_isomap(),
step_kpca(),
step_kpca_poly(),
step_kpca_rbf(),
step_mutate_at(),
step_nnmf(),
step_nnmf_sparse(),
step_pls(),
step_ratio(),
step_spatialsign()
rec <- recipe(~., data = USArrests)
pca_trans <- rec |>
step_normalize(all_numeric()) |>
step_pca(all_numeric(), num_comp = 3)
pca_estimates <- prep(pca_trans, training = USArrests)
pca_data <- bake(pca_estimates, USArrests)
rng <- extendrange(c(pca_data$PC1, pca_data$PC2))
plot(pca_data$PC1, pca_data$PC2,
xlim = rng, ylim = rng
)
with_thresh <- rec |>
step_normalize(all_numeric()) |>
step_pca(all_numeric(), threshold = .99)
with_thresh <- prep(with_thresh, training = USArrests)
bake(with_thresh, USArrests)
tidy(pca_trans, number = 2)
tidy(pca_estimates, number = 2)
tidy(pca_estimates, number = 2, type = "variance")
Run the code above in your browser using DataLab